@@ -9,9 +9,10 @@ friendly API surface and `help()` output.
 
 from __future__ import annotations
 
+import time
 import calendar
 import datetime
-from datetime import date, time, timedelta, timezone
+import datetime 
 from typing import Optional, Union
 from zoneinfo import ZoneInfo
 
@@ -54,6 +55,8 @@ __all__ = [
     "is_weekday",
     "is_weekend",
     "days_in_month",
+    "sleep",        
+    "sleep_until",
 ]
 
 
@@ -106,10 +109,56 @@ is_leap_year(year: int) -> bool: Return True if `year` is a leap year.
 is_weekday(dt: datetime.datetime) -> bool: Return True if dt is Monday-Friday.
 is_weekend(dt: datetime.datetime) -> bool: Return True if dt is Saturday or Sunday.
 days_in_month(year: int, month: int) -> int: Return number of days in a given month/year.
+sleep(seconds: Union[int, float]) -> None: Sleep for the specified number of seconds.
+sleep_until(target_time: datetime) -> None: Sleep until the specified datetime.
 """
     )
 
 
+def sleep(seconds: Union[int, float]) -> None:
+    """
+    Sleep for the specified number of seconds.
+    
+    This is a convenience wrapper around time.sleep() that provides
+    proper type hints and integrates with the datetime module.
+    
+    Args:
+        seconds: Number of seconds to sleep. Can be integer or float.
+    
+    Examples:
+        >>> sleep(5)          # Sleep for 5 seconds
+        >>> sleep(0.5)        # Sleep for 500 milliseconds
+        >>> sleep(2.5)        # Sleep for 2.5 seconds
+    
+    Raises:
+        ValueError: If seconds is negative.
+    """
+    if seconds < 0:
+        raise ValueError(f"Cannot sleep for negative time: {seconds} seconds")
+    
+    time.sleep(seconds)
+
+
+def sleep_until(target_time: datetime) -> None:
+    """
+    Sleep until the specified datetime.
+    
+    Args:
+        target_time: The datetime to sleep until.
+    
+    Raises:
+        ValueError: If target_time is in the past.
+    """
+    now = datetime.now(target_time.tzinfo if target_time.tzinfo else None)
+    sleep_seconds = (target_time - now).total_seconds()
+    
+    if sleep_seconds < 0:
+        raise ValueError(f"Target time {target_time} is in the past (current time: {now})")
+    
+    sleep(sleep_seconds)
+
+
+
 # ========================
 # Current Time
 # ========================
