@@ -476,15 +476,161 @@ def parse_json(s: str) -> Dict[str, Any]:
         log.error(f"Invalid JSON: {e}")
         raise StringsError(f"Invalid JSON: {e}") from e
 def parse_yaml(s: str) -> Dict[str, Any]:
-    """Parse YAML string to Python data structure using ruamel.yaml."""
+    """Parse YAML string to Python data structure using ruamel.yaml with enhanced error handling."""
     yaml = ruamel.yaml.YAML()
+    yaml.preserve_quotes = True
+    
     try:
-        data = yaml.load(s)
+        # ✅ Pre-process the YAML to fix common issues
+        cleaned_yaml = _preprocess_yaml(s)
+        
+        data = yaml.load(cleaned_yaml)
+        
+        # ✅ Handle empty or None result
+        if data is None:
+            log.warning("YAML parsed as None (empty or comment-only file)")
+            return {}
+        
         log.debug(f"Parsed YAML: {data}")
         return data
+        
     except ruamel.yaml.YAMLError as e:
         log.error(f"Invalid YAML: {e}")
+        
+        # ✅ Try to provide helpful error messages
+        if "mapping" in str(e) and "sequence" in str(e):
+            log.error("This often indicates mixed indentation or incorrect YAML structure")
+        elif "line" in str(e) and "column" in str(e):
+            log.error("Check the specific line and column mentioned for syntax errors")
+        
         raise StringsError(f"Invalid YAML: {e}") from e
+
+def _preprocess_yaml(yaml_content: str) -> str:
+    """Pre-process YAML content to fix common issues before parsing."""
+    lines = yaml_content.splitlines()
+    cleaned_lines = []
+    
+    for i, line in enumerate(lines):
+        cleaned_line = line
+        
+        # ✅ Fix: Remove inline comments that might break parsing
+        if '#' in line and not line.strip().startswith('#'):
+            # Keep the content before the comment, but be careful with URLs
+            if '://' not in line.split('#')[0]:  # Don't break URLs
+                cleaned_line = line.split('#')[0].rstrip()
+        
+        # ✅ Fix: Detect and warn about inconsistent indentation
+        if cleaned_line.strip() and not cleaned_line.strip().startswith('#'):
+            # Count leading spaces for indentation
+            leading_spaces = len(cleaned_line) - len(cleaned_line.lstrip())
+            if leading_spaces % 2 != 0 and leading_spaces > 0:
+                log.warning(f"Line {i+1}: Odd indentation ({leading_spaces} spaces) might cause issues")
+        
+        cleaned_lines.append(cleaned_line)
+    
+    return '\n'.join(cleaned_lines)
+
+
+def validate_yaml(s: str) -> Dict[str, Any]:
+    """
+    Validate YAML syntax and structure with detailed error reporting.
+    
+    Returns:
+        Dict with validation results:
+        - 'valid': bool indicating if YAML is valid
+        - 'errors': list of error messages
+        - 'warnings': list of warning messages  
+        - 'data': parsed data if valid, else None
+        - 'line_count': number of lines
+        - 'structure': basic structure info
+    """
+    result = {
+        'valid': False,
+        'errors': [],
+        'warnings': [],
+        'data': None,
+        'line_count': len(s.splitlines()),
+        'structure': {}
+    }
+    
+    # Basic checks
+    if not s.strip():
+        result['errors'].append("YAML is empty")
+        return result
+    
+    # Try to parse with detailed error info
+    try:
+        yaml = ruamel.yaml.YAML()
+        data = yaml.load(s)
+        result['data'] = data if data is not None else {}
+        result['valid'] = True
+        
+        # Analyze structure
+        if data:
+            result['structure'] = {
+                'keys': list(data.keys()) if isinstance(data, dict) else ['list'],
+                'type': type(data).__name__,
+                'services_count': len(data.get('services', {})) if isinstance(data, dict) else 0
+            }
+        
+    except ruamel.yaml.YAMLError as e:
+        error_msg = str(e)
+        result['errors'].append(error_msg)
+        
+        # Extract line number from error message if possible
+        line_match = re.search(r'line\s+(\d+)', error_msg, re.IGNORECASE)
+        if line_match:
+            line_num = int(line_match.group(1))
+            lines = s.splitlines()
+            if 0 <= line_num - 1 < len(lines):
+                result['errors'].append(f"Problem near line {line_num}: {lines[line_num-1]}")
+    
+    # Check for common issues
+    lines = s.splitlines()
+    for i, line in enumerate(lines):
+        # Check for tabs (YAML should use spaces)
+        if '\t' in line:
+            result['warnings'].append(f"Line {i+1}: Contains tabs (should use spaces)")
+        
+        # Check for inconsistent indentation
+        if line.strip() and not line.strip().startswith('#'):
+            leading_spaces = len(line) - len(line.lstrip())
+            if leading_spaces > 0 and ' ' in line[:leading_spaces] and '\t' in line[:leading_spaces]:
+                result['warnings'].append(f"Line {i+1}: Mixed tabs and spaces in indentation")
+    
+    return result
+
+def safe_parse_yaml(s: str, default: Dict[str, Any] = None) -> Dict[str, Any]:
+    """
+    Safely parse YAML with comprehensive error handling and fallback.
+    
+    Args:
+        s: YAML string to parse
+        default: Default value to return if parsing fails
+        
+    Returns:
+        Parsed data or default value on error
+    """
+    if default is None:
+        default = {}
+    
+    try:
+        return parse_yaml(s)
+    except StringsError as e:
+        log.error(f"YAML parsing failed: {e}")
+        
+        # ✅ Try to extract basic structure even from invalid YAML
+        try:
+            # Fallback to basic YAML loader without advanced features
+            basic_data = ruamel.yaml.safe_load(s)
+            if basic_data is not None:
+                log.warning("Using basic YAML parser as fallback")
+                return basic_data
+        except Exception:
+            pass
+        
+        log.error("Could not parse YAML with any method")
+        return default
 def parse_ini(s: str) -> Dict[str, Dict[str, str]]:
     """Parse INI string to nested dict."""
     config = configparser.ConfigParser()
